@@ -4,7 +4,7 @@ from bluer_algo.socket.classes import SocketComm, DEV_HOST
 from bluer_sbc.imager.camera import instance as camera
 from bluer_sbc.env import BLUER_SBC_ENV
 
-from bluer_ugv.swallow.session.classical.keyboard import ClassicalKeyboard
+from bluer_ugv.swallow.session.classical.keyboard.classes import ClassicalKeyboard
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
 from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
 from bluer_ugv.logger import logger
@@ -36,5 +36,9 @@ class ClassicalCamera:
         socket = SocketComm.connect_to(DEV_HOST)
         return socket.send_data(data)
 
+    # multi-threaded support
+    def stop(self):
+        pass
+
     def update(self) -> bool:
         return True
