@@ -1,9 +1,8 @@
 from typing import List
-import numpy as np
+import threading
 
 from bluer_options.timer import Timer
 from bluer_options import string
-from bluer_options import host
 from bluer_objects.storage.policies import DownloadPolicy
 from bluer_objects import storage
 from bluer_objects.metadata import post_to_object, get_from_object
@@ -14,7 +13,7 @@ from bluer_algo.yolo.model.predictor import YoloPredictor
 
 from bluer_ugv import env
 from bluer_ugv.swallow.session.classical.camera.generic import ClassicalCamera
-from bluer_ugv.swallow.session.classical.keyboard import ClassicalKeyboard
+from bluer_ugv.swallow.session.classical.keyboard.classes import ClassicalKeyboard
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
 from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
 from bluer_ugv.swallow.session.classical.mode import OperationMode
@@ -47,32 +46,45 @@ class ClassicalYoloCamera(ClassicalCamera):
             create=True,
         )
 
-        self.predictor = None
-
-        self.action_enabled: bool = True
-
-    def initialize(self) -> bool:
-        if not super().initialize():
-            return False
+        assert super().initialize()
 
         if not storage.download(
             env.BLUER_UGV_SWALLOW_YOLO_MODEL,
             policy=DownloadPolicy.DOESNT_EXIST,
         ):
-            return False
+            logger.error("cannot download the model.")
 
         success, self.predictor = YoloPredictor.load(
             object_name=env.BLUER_UGV_SWALLOW_YOLO_MODEL,
             image_size=BLUER_SBC_CAMERA_WIDTH,
         )
-        return success
+        if not success:
+            logger.error("cannot create the predictor.")
+
+        self.running = True
+        self.thread = threading.Thread(target=self.loop, daemon=True)
+        self.thread.start()
+
+    # the parent method is called in the constructor
+    def initialize(self) -> bool:
+        return True
 
     def cleanup(self):
+        return True
+
+    # the parent method is called in stop()
+    def stop(self):
+        self.running = False
+        self.thread.join()
+
+        logger.info(f"{self.__class__.__name__}.stopped.")
+
         super().cleanup()
 
-        self.dataset.save(
+        if not self.dataset.save(
             verbose=True,
-        )
+        ):
+            logger.error("cannot save the dataset.")
 
         if self.dataset.empty:
             return
@@ -93,31 +105,26 @@ class ClassicalYoloCamera(ClassicalCamera):
         ):
             logger.error("failed to add object to dataset list.")
 
-    def update(self) -> bool:
-        if not super().update():
-            return False
+    def loop(self):
+        logger.info(f"{self.__class__.__name__}.loop started.")
 
-        if self.keyboard.mode == OperationMode.ACTION:
-            return self.update_action()
+        while self.running:
+            mode = self.keyboard.get("mode", OperationMode.NONE)
 
-        if self.keyboard.mode == OperationMode.TRAINING:
-            return self.update_training()
+            success = True
+            if mode == OperationMode.ACTION:
+                success = self.loop_action()
 
-        return True
+            if mode == OperationMode.TRAINING:
+                success = self.loop_training()
 
-    def update_action(self) -> bool:
+            if not success:
+                logger.error(f"loop failed, mode: {mode.name.lower()}.")
+
+    def loop_action(self) -> bool:
         if not self.prediction_timer.tick():
             return True
 
-        self.action_enabled = not self.action_enabled
-        if not self.action_enabled:
-            self.setpoint.put(
-                what="steering",
-                value=0,
-                log=True,
-            )
-            return True
-
         self.leds.flash("red")
 
         success, image = camera.capture(
@@ -128,15 +135,16 @@ class ClassicalYoloCamera(ClassicalCamera):
         if not success:
             return success
 
+        debug_mode = self.keyboard.get("debug_mode", False)
         success, metadata = self.predictor.predict(
             image=image,
-            return_annotated_image=self.keyboard.debug_mode,
+            return_annotated_image=debug_mode,
             annotated_image_scale=2,
         )
         if not success:
             return success
 
-        if self.keyboard.debug_mode:
+        if debug_mode:
             if not self.send_debug_data(metadata["annotated_image"]):
                 logger.warning("failed to send debug data.")
 
@@ -152,17 +160,19 @@ class ClassicalYoloCamera(ClassicalCamera):
                 what="steering",
                 value=env.BLUER_UGV_SWALLOW_STEERING_SETPOINT,
                 log=True,
+                steering_expires_in=env.BLUER_UGV_SWALLOW_STEERING_YOLO_EXPIRY,
             )
         else:
             self.setpoint.put(
                 what="steering",
                 value=-env.BLUER_UGV_SWALLOW_STEERING_SETPOINT,
                 log=True,
+                steering_expires_in=env.BLUER_UGV_SWALLOW_STEERING_YOLO_EXPIRY,
             )
 
         return True
 
-    def update_training(self) -> bool:
+    def loop_training(self) -> bool:
         if not (self.training_timer.tick() or self.keyboard.last_key != ""):
             return True
 
