@@ -1,5 +1,6 @@
 from typing import List, Tuple
 
+from bluer_ugv import env
 from bluer_ugv.swallow.session.classical.ultrasonic_sensor.sensor import (
     lUltrasonicSensor,
 )
@@ -11,7 +12,7 @@ class UltrasonicSensorPack:
     def __init__(
         self,
         setmode: bool = True,
-        max_m: float = 0.8,
+        max_m: float = env.BLUER_UGV_ULTRASONIC_SENSOR_MAX_M,
     ) -> None:
         self.left = lUltrasonicSensor(
             side="left",
