@@ -12,9 +12,18 @@ NAME = module.name(__file__, NAME)
 
 def review(
     object_name: str,
+    export_gif: bool = False,
+    frame_count: int = -1,
     log: bool = True,
+    rm_blank: bool = True,
 ) -> bool:
-    logger.info("{}.review({})".format(NAME, object_name))
+    logger.info(
+        "{}.review{}: {}".format(
+            NAME,
+            f" [{frame_count} frame(s)]" if frame_count == -1 else "",
+            object_name,
+        )
+    )
 
     detection_log = UltrasonicSensorDetectionLog()
 
@@ -26,7 +35,10 @@ def review(
     if not detection_log.export(
         object_name=object_name,
         line_width=80,
+        export_gif=export_gif,
+        frame_count=frame_count,
         log=log,
+        rm_blank=rm_blank,
     ):
         return False
 
